@@ -1,7 +1,7 @@
 package App::CalcAccumulatedInflation;
 
-our $DATE = '2015-12-18'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-03-09'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ _
         },
         rates => {
             summary => 'Different rates for each year, in percent',
-            schema  => ['array*', of=>'float*', min_len=>1],
+            schema  => ['array*', of=>'float*', min_len=>1, 'x.perl.coerce_rules'=>['str_comma_sep']],
         },
         yearly_rate => {
             summary => 'A single rate for every year, in percent',
@@ -70,12 +70,13 @@ sub calc_accumulated_inflation {
         }
     } else {
         my $rates = $args{rates};
-        while ($year < $#{$rates}) {
-            $index *= 1 + $rates->[$year]/100;
+        while ($year <= $#{$rates}) {
+            my $rate = $rates->[$year];
+            $index *= 1 + $rate/100;
             $year++;
             push @res, {
                 year  => $year,
-                rate  => sprintf("%.2f%%", $rates->[$year]),
+                rate  => sprintf("%.2f%%", $rate),
                 index => sprintf("%.4f", $index),
             };
         }
@@ -99,7 +100,7 @@ App::CalcAccumulatedInflation - Calculate accumulated inflation over the years
 
 =head1 VERSION
 
-This document describes version 0.02 of App::CalcAccumulatedInflation (from Perl distribution App-CalcAccumulatedInflation), released on 2015-12-18.
+This document describes version 0.03 of App::CalcAccumulatedInflation (from Perl distribution App-CalcAccumulatedInflation), released on 2017-03-09.
 
 =head1 SYNOPSIS
 
@@ -108,7 +109,11 @@ See the included script L<calc-accumulated-inflation>.
 =head1 FUNCTIONS
 
 
-=head2 calc_accumulated_inflation(%args) -> any
+=head2 calc_accumulated_inflation
+
+Usage:
+
+ calc_accumulated_inflation(%args) -> any
 
 Calculate accumulated inflation over the years.
 
@@ -116,11 +121,9 @@ Examples:
 
 =over
 
-=item *
+=item * See accumulated 6%/year inflation for 10 years:
 
-See accumulated 6%/year inflation for 10 years:
-
- calc_accumulated_inflation( yearly_rate => 6);
+ calc_accumulated_inflation(yearly_rate => 6);
 
 Result:
 
@@ -138,27 +141,26 @@ Result:
    { index => 1.7908, year => 10 },
  ]
 
-=item *
+=item * Indonesia's inflation rate for 2003-2014:
 
-Indonesia's inflation rate for 2003-2014:
-
- calc_accumulated_inflation(  rates => [5.16, 6.4, 17.11, 6.6, 6.59, 11.06, 2.78, 6.96, 3.79, 4.3, 8.38, 8.36]);
+ calc_accumulated_inflation(rates => [5.16, 6.4, 17.11, 6.6, 6.59, 11.06, 2.78, 6.96, 3.79, 4.3, 8.38, 8.36]);
 
 Result:
 
  [
    { index => 1, year => 0 },
-   { index => 1.0516, rate => "6.40%", year => 1 },
-   { index => 1.1189, rate => "17.11%", year => 2 },
-   { index => 1.3103, rate => "6.60%", year => 3 },
-   { index => 1.3968, rate => "6.59%", year => 4 },
-   { index => 1.4889, rate => "11.06%", year => 5 },
-   { index => 1.6536, rate => "2.78%", year => 6 },
-   { index => 1.6995, rate => "6.96%", year => 7 },
-   { index => 1.8178, rate => "3.79%", year => 8 },
-   { index => 1.8867, rate => "4.30%", year => 9 },
-   { index => 1.9678, rate => "8.38%", year => 10 },
-   { index => 2.1327, rate => "8.36%", year => 11 },
+   { index => 1.0516, rate => "5.16%", year => 1 },
+   { index => 1.1189, rate => "6.40%", year => 2 },
+   { index => 1.3103, rate => "17.11%", year => 3 },
+   { index => 1.3968, rate => "6.60%", year => 4 },
+   { index => 1.4889, rate => "6.59%", year => 5 },
+   { index => 1.6536, rate => "11.06%", year => 6 },
+   { index => 1.6995, rate => "2.78%", year => 7 },
+   { index => 1.8178, rate => "6.96%", year => 8 },
+   { index => 1.8867, rate => "3.79%", year => 9 },
+   { index => 1.9678, rate => "4.30%", year => 10 },
+   { index => 2.1327, rate => "8.38%", year => 11 },
+   { index => "2.3110", rate => "8.36%", year => 12 },
  ]
 
 =back
@@ -167,7 +169,7 @@ This routine generates a table of accumulated inflation over a period of several
 years. You can either specify a fixed rate for every years (C<yearly_rate>), or
 specify each year's rates (C<rates>).
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -209,7 +211,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
